@@ -23,6 +23,10 @@ from ...common import get_sys_config, get_proj_config
 from uuid import uuid4
 from uuid import UUID as UUID_type
 from typing import Optional, Tuple
+import logging
+
+
+logger = logging.getLogger()
 
 
 class ViewerWorkEnv:
@@ -136,7 +140,7 @@ class ViewerWorkEnv:
         self.origin_file = ''
         self._saved = True
         self.changed_items = []
-        print('Work environment dumped!')
+        logger.info('Work environment dumped!')
 
     def restore_rois_from_states(self):
         if (self.roi_manager is not None) and (self.roi_states is not None):
@@ -156,7 +160,13 @@ class ViewerWorkEnv:
         if tiff_path is not None:
             # seq = tifffile.imread(tiff_path)
             tif = tifffile.TiffFile(tiff_path, is_nih=True)
-            seq = tif.asarray(maxworkers=int(get_sys_config()['_MESMERIZE_N_THREADS']))
+            if len(tif.series) > 1:
+                seq = tif.asarray(
+                    key=range(0, len(tif.series)),
+                    maxworkers=int(get_sys_config()['_MESMERIZE_N_THREADS'])
+                )
+            else:
+                seq = tif.asarray(maxworkers=int(get_sys_config()['_MESMERIZE_N_THREADS']))
             if seq.ndim == 4:
                 # tzxy to xytz
                 seq = np.moveaxis(seq, (0, 1, 2, 3), (2, 3, 0, 1))
